Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(264)

Unified Diff: components/mus/public/cpp/window_tree_host_factory.h

Issue 1674903003: Extract shell methods from ApplicationImpl into a base class, and pass this to Initialize() instead. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@mojom
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/mus/public/cpp/window_tree_connection.h ('k') | components/mus/ws/display_manager.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/mus/public/cpp/window_tree_host_factory.h
diff --git a/components/mus/public/cpp/window_tree_host_factory.h b/components/mus/public/cpp/window_tree_host_factory.h
index c466074ee47e0cec26996842351d8a77e70384a3..1c75de812e49bef4f94c54e9b6bbd2dea48c1ec3 100644
--- a/components/mus/public/cpp/window_tree_host_factory.h
+++ b/components/mus/public/cpp/window_tree_host_factory.h
@@ -11,7 +11,7 @@
#include "mojo/public/cpp/bindings/binding.h"
namespace mojo {
-class ApplicationImpl;
+class Shell;
}
namespace mus {
@@ -20,13 +20,13 @@ class WindowManagerDelegate;
class WindowTreeDelegate;
// The following create a new window tree host. Supply a |factory| if you have
// already connected to mus, otherwise supply |app|, which contacts mus and
// obtains a WindowTreeHostFactory.
void CreateWindowTreeHost(mojom::WindowTreeHostFactory* factory,
WindowTreeDelegate* delegate,
mojom::WindowTreeHostPtr* host,
WindowManagerDelegate* window_manager_delegate);
-void CreateWindowTreeHost(mojo::ApplicationImpl* app,
+void CreateWindowTreeHost(mojo::Shell* shell,
WindowTreeDelegate* delegate,
mojom::WindowTreeHostPtr* host,
WindowManagerDelegate* window_manager_delegate);
@@ -20,13 +20,13 @@ class WindowManagerDelegate;
class WindowTreeDelegate;
// The following create a new window tree host. Supply a |factory| if you have
-// already connected to mus, otherwise supply |app|, which contacts mus and
+// already connected to mus, otherwise supply |shell|, which contacts mus and
// obtains a WindowTreeHostFactory.
void CreateWindowTreeHost(mojom::WindowTreeHostFactory* factory,
« no previous file with comments | « components/mus/public/cpp/window_tree_connection.h ('k') | components/mus/ws/display_manager.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698